import { CacheType, ChatInputCommandInteraction, Message, PermissionFlagsBits, SlashCommandBuilder } from 'discord.js';
import ConfigManager from '../controller/ConfigManager';
import EcoManager from '../controller/EcoManager';

export default {
  data: new SlashCommandBuilder()
    .setName('message')
    .setDescription('Message to game')
    .addStringOption(opt => opt.setName("message").setDescription("Message").setRequired(true))
    .addStringOption(opt => opt.setName("to").setDescription("Destination (#General,@User)").setRequired(true))
    .addStringOption(opt => opt.setName("from").setDescription("Source").setRequired(false))
    .setDefaultMemberPermissions(PermissionFlagsBits.Administrator),
  async execute(interaction: ChatInputCommandInteraction<CacheType>, config: ConfigManager) {
    const ecoManager = new EcoManager(config)

    var message = interaction.options.getString('message')
    var from = interaction.options.getString('from')
    var to = interaction.options.getString('to')

    if (!from)
      from = interaction.user.username

    await interaction.deferReply({ ephemeral: true })

    try {
      if (!message || !from || !to) {
        await interaction.followUp(`Ошибка отправки сообщения`);
        return
      }

      const status = await ecoManager.Message(message, from, to)
      if (!!status && status.Success) {
        await interaction.followUp("Сообщение отправлено")
      } else {
        await interaction.followUp("Ошибка отправки сообщения")
      }
      return
    } catch (error) {
      await interaction.editReply("Ошибка отправки сообщения")
      console.log(error)
    }
  },
};
