import { ActionRowBuilder, ButtonBuilder, ButtonStyle, CacheType, ChatInputCommandInteraction, Message } from "discord.js";
import ConfigManager from "./ConfigManager";
import axios from "axios";
import UserI from "../types/UserI";
import CommandReplyI from "../types/CommandReplyI";
import MessageReplyI from "../types/MessageReplyI";

export default class EcoManager {
  config: ConfigManager
  public constructor(config: ConfigManager) {
    this.config = config
  }
  public async Alert(message: string) {
    if (!message) return null
    return await this.Exec(`manage alert ${message}`)
  }
  public async Exec(command: string) {
    if (!command) return null
    try {
      const { data, status } = await axios<CommandReplyI>(`${process.env.ECO_API_BASE || "https://eco.kamgames.xyz"}/api/v1/command/exec`, {
        method: "POST",
        timeout: 5000,
        headers: {
          "X-API-Key": process.env.ECO_API_KEY,
        },
        data: {
          Command: command
        },
      });

      if (status !== 200) return null

      return data
    } catch (error) {
      console.log(error)
    }
    return null
  }
  public async Message(message: string, from: string, to: string) {
    if (!message || !from || !to) return null
    if (to[0] !== "#" && to[0] !== "@") return null
    if (to[0] === "#")
      to = `%23${to.slice(1)}`
    from = from.replaceAll(" ", "%20")
    try {
      const { data, status } = await axios<MessageReplyI>(`${process.env.ECO_API_BASE || "https://eco.kamgames.xyz"}/api/v1/chat/sendChat?username=${from}&message=${to}%20${message}`, {
        method: "GET",
        timeout: 5000,
        headers: {
          "X-API-Key": process.env.ECO_API_KEY,
        },
      });

      if (status !== 200) return null

      return data
    } catch (error) {
      console.log(error)
    }
    return null
  }
}